Change log for µSpectre
=======================

0.9.1 (17Jun20)
---------------
- Bug fix: Packaging with sdist only included FFT engines present during
  the packaging process

0.9.0 (17Jun20)
---------------
- Initial release of µSpectre
  * FFT based micromechanical homogeneization
  * Arbitrary constitutive laws in small and finite strain
  * Krylov and Newton solver suite
  * MPI parallelization
- Initial release of µFFT
  * Generic wrapper for MPI-parallel FFT libraries
- Initial release of µGrid
  * Generic library for managing regular grids
